import React from 'react'
import DefaultLayout from '@/layouts/DefaultLayout/DefaultLayout'
import BookReview from '@/components/Book/BookReview'
import { fetchBookReviews, markdownToHtml } from '@/services/content-service'
import { FailedFetchBookReviewError, FailedFetchBookReviewsError } from '@/errors'

// export async function getStaticPaths () {
//   const res = await fetchBookReviews(['slug'], {
//     status: 'published'
//   })

//   if (!res.ok) {
//     throw new FailedFetchBookReviewsError(await res.text())
//   }

//   const reviews = (await res.json()).data

//   return {
//     paths: reviews.map(post => ({
//       params: {
//         slug: post.slug
//       }
//     })),
//     fallback: false // false or "blocking"
//   }
// }

export const getServerSideProps = async ({ params }) => {
  const { slug } = params

  if (!slug) {
    return {
      notFound: true
    }
  }

  const res = await fetchBookReviews([], {
    slug,
    status: 'published'
  })

  if (!res.ok) {
    throw new FailedFetchBookReviewError(slug, await res.text())
  }

  const review = (await res.json()).data.at(0)
  if (!review) {
    return {
      notFound: true
    }
  }

  const content = review.review
  const html = markdownToHtml(content)

  return {
    props: {
      review,
      html
    }
  }
}

export default function LibrarySingle ({ review, html }) {
  return (
    <DefaultLayout>
      <BookReview review={review} html={html} />
    </DefaultLayout>
  )
}
